import React, { useEffect, useState } from 'react'
import { Card, Form, Input, Button, Select, message } from 'antd'
import styles from './messageConfig.less';
import { GetMessageConfigInfo, SaveSystemInfo, ConnectMessPlatform, GetBasicInfo, GetDataBaseConfig } from '@/services/platform/hostmanager'


const layout = {
    labelCol: { span: 8 },
    wrapperCol: { span: 16 },

};
const tailLayout = {
    wrapperCol: { offset: 8, span: 16 },

};
const MessageConfig = () => {


    const [currentAddress, setCurrentAddress] = useState("")
    const [currentDataBase, setCurrentDataBase] = useState({});
    const [currentSiteInfo, setcurrentSiteInfo] = useState("");

    const [form] = Form.useForm();
    const onFinish = (values) => {
        //先测试连接再保存
        //1.测试链接
        ConnectMessPlatform({
            messAddress: values.messageAddress,
            sqlServerIP: currentDataBase.ip,
            loginName: currentDataBase.userName,
            password: currentDataBase.password,
            sqlName: currentDataBase.dbName,
            siteCode: currentSiteInfo
        }).then(res => {
            if (res.code === 0) {
                //2.保存连接
                SaveSystemInfo({
                    configName: "消息平台连接地址",
                    configValue: values.messageAddress
                }).then(
                    res => {
                        if (res.code === 0) {
                            message.info("配置保存成功")
                        } else {
                            message.errorInfo(res.msg)
                        }
                    }
                )
            } else {
                message.errorInfo(res.msg)
            }
        })

    };

    const onFinishFailed = (errorInfo) => {
        console.log('Failed:', errorInfo);
    };



    useEffect(() => {
        GetMessageConfigInfo().then(
            res => {
                if (res.code == 0) {
                    setCurrentAddress(res.data)
                    form.setFieldsValue({ messageAddress: res.data });
                    GetDataBaseConfig().then(
                        res => {
                            if (res.code === 0) {
                                setCurrentDataBase(res.data)
                                GetBasicInfo().then(
                                    res => {
                                        if (res.code === 0) {
                                            setcurrentSiteInfo(res.data)
                                        }
                                    }
                                )
                            }
                        }
                    )
                } else {
                    message.info("获取消息平台配置失败!")
                }

            }
        )


    }, [])



    return (
        <div className={styles.message_container}>
            <Card title={`消息平台`} style={{ width: 430 }}>

                <Form
                    {...layout}
                    form={form}
                    name="basic"
                    initialValues={{ remember: true }}
                    onFinish={onFinish}
                    onFinishFailed={onFinishFailed}
                >
                    <Form.Item
                        label="服务器地址(平台)"
                        name="messageAddress"
                        rules={[{ required: true, message: '请输入域名(IP):端口,例如:192.168.19.102:8131' }]}

                    >
                        <Input />
                    </Form.Item>
                    <Form.Item {...tailLayout}>
                        <Button type="primary" htmlType="submit" disabled={currentSiteInfo.length > 0 ? false : true}>
                            保存连接
                        </Button>
                    </Form.Item>
                </Form>
            </Card>
        </div>
    )
}
export default MessageConfig