import React, { useEffect, useState } from 'react'
import { Card, Form, Input, Button, Switch, message } from 'antd'
import styles from './ProxyConfig.less'
import { GetNginxConfigInfo, InsertNginxConfig, StartNginx, StopNginx, ReloadNginx, NginxCache, NginxLog } from '@/services/platform/hostmanager'
import { ReloadOutlined } from '@ant-design/icons';

const layout = {
    labelCol: { span: 8 },
    wrapperCol: { span: 16 },

};
const tailLayout = {
    wrapperCol: { offset: 8, span: 16 },

};

const ProxyConfig = () => {
    

    const [form] = Form.useForm();

    const [flag, setFlag] = useState(1)
    const [currentConfig, setCurrentConfig] = useState({
        NginxPort: "",
        IISIPProt: "",
        EMQIPPort: "",
        IsStartNginx: false,
        IsStartNginxCache: false,
        IsStartNginxLog: false

    })
    const onFinish = (values) => {
        InsertNginxConfig({
            port: values.NginxPort,
            iisLocation: values.IISIPProt,
            emqLocation: values.EMQIPPort
        }).then(
            res => {
                if (res.code === 0) {
                    message.success("保存成功")
                } else {
                    message.error("保存失败")
                }
            }
        )
    };

    const onFinishFailed = (errorInfo) => {

    };

    const OperateNginx = (checked) => {
        if (checked) {
            OperateStartNginx()
        } else {
            OperateStopNginx()
        }
    }
    //开启Nginx
    const OperateStartNginx = () => {
        StartNginx().then(
            res => {
                if (res.code === 0) {
                    message.success("开启成功")
                    setFlag(flag + 1)
                } else {
                    message.error("开启失败")
                }
            }
        )
    }
    //停止Nginx
    const OperateStopNginx = () => {
        StopNginx().then(
            res => {
                if (res.code === 0) {
                    message.success("关闭成功")
                    setFlag(flag + 1)
                } else {
                    message.error("关闭失败")
                }
            }
        )
    }
    //开启/关闭缓存
    const OperateNginxCache = (isOpen) => {
        NginxCache({
            isOpen: isOpen ? 1 : 0,
        }).then(
            res => {
                if (res.code === 0) {
                    setFlag(flag + 1)
                    message.success(isOpen ? "开启成功" : "关闭成功")

                } else {
                    message.error(res.msg)
                }
            }
        )
    }
    //开启/关闭日志
    const OperateNginxLog = (isOpen) => {
        NginxLog({
            isOpen: isOpen ? 1 : 0,

        }).then(
            res => {
                if (res.code === 0) {
                    setFlag(flag + 1)
                    message.success(isOpen ? "开启成功" : "关闭成功")
                } else {
                    message.error(res.msg)
                }
            }
        )
    }


    const OperateReloadNginx = () => {
        ReloadNginx().then(
            res => {
                if (res.code === 0) {
                    message.success("重载成功")
                } else {
                    message.error("重载失败")
                }
            }
        )
    }

    useEffect(() => {
        GetNginxConfigInfo().then(
            res => {
                if (res.code === 0) {
                    setCurrentConfig({
                        NginxPort: res.data.NginxPort,
                        IISIPPort: res.data.IISIPPort,
                        EMQIPPort: res.data.EMQIPPort,
                        IsStartNginx: res.data.IsStartNginx,
                        IsStartNginxCache: res.data.IsStartNginxCache,
                        IsStartNginxLog: res.data.IsStartNginxLog,
                    })
                    let obj = {};
                    Object.keys(currentConfig).forEach(k => {
                        obj[k] = res.data[k];
                    });
                    console.log(obj)
                    form.setFieldsValue(obj);
                } else {
                    message.errorInfo(res.msg)
                }
            }
        )
    }, [flag])
    //     GetNginxConfigInfoOLD().then(
    //         res => {
    //             if (res.say.statusCode === "0000") {
    //                 setCurrentConfig({
    //                     NginxPort: res.getMe[0].NginxPort,
    //                     IISIPProt: res.getMe[0].IISIPProt,
    //                     EMQIPPort: res.getMe[0].EMQIPPort,
    //                     IsStartNginx: res.getMe[0].IsStartNginx,
    //                     IsStartNginxCache: res.getMe[0].IsStartNginxCache,
    //                     IsStartNginxLog: res.getMe[0].IsStartNginxLog,
    //                 })
    //                 let obj = {};
    //                 Object.keys(currentConfig).forEach(k => {
    //                     obj[k] = res.getMe[0][k];
    //                 });
    //                 console.log(obj)
    //                 form.setFieldsValue(obj);
    //             } else {
    //                 message.errorInfo(res.msg)
    //             }
    //         }
    //     )
    // }, [])

    return (
        <div className={styles.proxy_container}>
            <Card title="配置文件管理" style={{ width: 350 }}>
                <Form
                    {...layout}
                    form={form}
                    name="basic"
                    initialValues={{ remember: true }}
                    onFinish={onFinish}
                    onFinishFailed={onFinishFailed}
                >
                    <Form.Item
                        label="端口(ngnix)"
                        name="NginxPort"
                        rules={[{ required: true,pattern: new RegExp(/^[1-9]\d*$/,'g'), message: '请输入ngnix端口,例如:8091' }]}

                    >
                        <Input />
                    </Form.Item>

                    <Form.Item
                        label="地址(IIS)"
                        name="IISIPProt"
                        rules={[{ required: true, message: '请输入服务器地址!' }]}
                        hasFeedback
                    >
                        <Input />
                    </Form.Item>
                    <Form.Item
                        label="地址(EMQ)"
                        name="EMQIPPort"
                        hasFeedback
                        rules={[{ required: true, message: '请选择是否!' }]}

                    >
                        <Input />
                    </Form.Item>
                    <Form.Item {...tailLayout}>
                        <Button type="primary" htmlType="submit" disabled={currentConfig.NginxPort.length > 0 ? 0 : 1}>
                            保存
                        </Button>
                    </Form.Item>
                </Form>

            </Card>
            <Card title="服务器管理" style={{ width: 350, marginLeft: 15 }}>
                <div className={styles.operate_container}>
                    <div className={styles.operate_item}>
                        <div>服务器运行</div>
                        <Switch checkedChildren='开启' unCheckedChildren='关闭' checked={currentConfig.IsStartNginx} onChange={OperateNginx} />
                    </div>
                    <div className={styles.operate_item}>
                        <div>服务器日志</div>
                        <Switch checkedChildren='开启' unCheckedChildren='关闭' checked={currentConfig.IsStartNginxLog} onChange={OperateNginxLog} disabled={currentConfig.IsStartNginx > 0 ? 0 : 1}/>
                    </div>
                    <div className={styles.operate_item}>
                        <div>服务器缓存</div>
                        <Switch checkedChildren='开启' unCheckedChildren='关闭' checked={currentConfig.IsStartNginxCache} onChange={OperateNginxCache} disabled={currentConfig.IsStartNginx > 0 ? 0 : 1}/>
                    </div>
                    <div className={styles.operate_item}>
                        <div>服务器重载</div>
                        <Button type="primary" icon={<ReloadOutlined />} onClick={OperateReloadNginx} disabled={currentConfig.IsStartNginx > 0 ? 0 : 1}>重载</Button>
                    </div>

                </div>
            </Card>
        </div>
    )
}
export default ProxyConfig;