import React, { useEffect, useState } from 'react'
import {
    // Tree,
    Table,
    Space,
    Input,
    Button,
    Select,
    Popconfirm,
    message
} from 'antd';
import { PlusCircleOutlined } from '@ant-design/icons';

const { Search } = Input;
const { Option } = Select;
import EditModal from './components/EditModal'
import AddModal from './components/AddModal'
import { GetMessageTemplate, UpdateMessageTemplate, DeleteMessageTemplate, InsertMessageTemplate, GetThirdpartyTemplates } from '@/services/platform/messagemanage'
import styles from './TemplateManage.less'



const TemplateManage = () => {

    const [visibleParams, setvisibleParams] = useState({
        addVisible: false, // 新增弹窗
        delVisible: false, // 删除弹窗
        editVisible: false, // 修改弹窗
        spinLoading: false, // 加载弹窗
        btnLoading: false,
        loading: false,
        checkBoxLoading: false,
    });
    const [currentTemplate, setCurrentTempalte] = useState({});
    const [data, setData] = useState([])
    const [flag,setFlag] = useState(0)


    useEffect(() => {
        getTemplateList()

    }, [flag])

    const getTemplateList = (obj) => {
        GetMessageTemplate(obj).then(
            res => {
                let list = []
                if (res.code === 0) {
                    res.data.map((item, index) => {
                        list.push({
                            key: item.Id,
                            Id:item.Id,
                            name: item.LikeName,
                            type: item.Type,
                            third_name: item.Name,
                            third_id:item.No,
                            template_params: item.TDescription,
                            analysis_params: item.ParsingRules,
                            desc: item.ParsingDescription
                        })
                    })
                    setData(list)
                }
            }
        )
    }
    const columns = [
        {
            title: '编号',
            dataIndex: 'Id',
            key: 'Id',
            render: text => <a>{text}</a>,
        },
        {
            title: '模板名称',
            dataIndex: 'name',
            key: 'name',
        },
        {
            title: '模板类型',
            dataIndex: 'type',
            key: 'type',
        },
        {
            title: '第三方模板名称',
            dataIndex: 'third_name',
            key: 'third_name',
        },
        {
            title: '第三方模版编号',
            dataIndex: 'third_id',
            key: 'third_id',
        },
        {
            title: '模板参数',
            dataIndex: 'template_params',
            key: 'template_params',
        },
        {
            title: '模板参数说明',
            dataIndex: 'desc',
            key: 'desc',
        },
        {
            title: '解析参数',
            dataIndex: 'analysis_params',
            key: 'analysis_params',
        },
        {
            title: '操作',
            dataIndex: 'action',
            key: 'action',
            width: 250,
            ellipsis: true,
            render: (text, record) => (
                <Space>
                    <Button
                        type="primary"
                        size="small"
                        onClick={() => {
                            changeDesc(record);
                        }}
                    >
                        编辑
                </Button>
                    <div onClick={e => e.stopPropagation()}>
                        <Popconfirm
                            title="是否删除该模板？"
                            okText="确认"
                            cancelText="取消"
                            onConfirm={() => {
                                delTemplate(record);
                            }}
                        >
                            <Button size="small" danger>
                                删除
                    </Button>
                        </Popconfirm>
                    </div>
                </Space>
            ),
        },

    ];

    const placeholder = '请输入模板名称'
    const handleSearch = (value) => {
        getTemplateList({ queryInfo: value })
    }
    const handleReset = () => {
        getTemplateList()
    }
    const handleSelectType = (value) => {
        if (value === '全部') {
            getTemplateList()
        } else {
            getTemplateList({ tempType: value })
        }
    }
    const changeDesc = (record) => {

        setCurrentTempalte(record)
        handleShowModal("editVisible", true)
    }
    const AddTemplate= ()=>{
        handleShowModal("addVisible", true)
    }
    const delTemplate = (record)=>{
        DeleteMessageTemplate({
            id:record.Id
        }).then(
            res =>{
                if(res.code === 0){
                    message.success("模板删除成功!")
                    setFlag(flag + 1)
                }else{
                    message.warn("模板删除失败!")
                }
            }
        )
    }
    // 弹出模态框
    const handleShowModal = (key, value) => {
        setvisibleParams({ ...visibleParams, [key]: value });
    };
    //编辑
    const editModal = () => {
        handleShowModal("editVisible", false)
    }
    const onSubmit = (result) => {
        console.log(result)
        UpdateMessageTemplate({
            Id:result.Id,
            Type:result.type,
            LikeName:result.name,
            Name:result.third_name,
            No:result.third_id,
            ParsingRules:result.analysis_params,
            ParsingDescription:result.desc,
            TDescription:result.params
        }).then(
            res =>{
                if(res.code === 0){
                    message.success("模板保存成功！")
                    handleShowModal("editVisible", false)
                    setFlag(flag + 1)
                }else{
                    message.warn("模板保存失败！")
                }
            }
        )
    }
    //新增
    const addModal = () => {
        handleShowModal("editVisible", false)
    }
    const onAddSubmit = (result) => {
        console.log(result)
        InsertMessageTemplate({
            Type:result.type,
            LikeName:result.name,
            Name:result.third_name,
            No:result.third_id,
            ParsingRules:result.analysis_params,
            ParsingDescription:result.desc,
            TDescription:result.params
        }).then(
            res =>{
                if(res.code === 0){
                    message.success("模板添加成功！")
                    handleShowModal("addVisible", false)
                    setFlag(flag + 1)
                }else{
                    message.warn("模板添加失败！")
                }
            }
        )
    }

    return (
        <div className={styles.template_container}>
            <div className={styles.operate_bar}>
                <div className={styles.template_type}>
                    <div className={styles.title}>模板类型</div>
                    <Select placeholder="请选择是否!" defaultValue="全部" onChange={handleSelectType}>
                        <Option value="全部">全部</Option>
                        <Option value="公众号">公众号</Option>
                        <Option value="短信">短信</Option>
                        <Option value="APP">APP</Option>
                        <Option value="WEB">WEB</Option>
                    </Select>
                </div>
                <div className={styles.fast_search}>
                    <div className={styles.title}>快速检索</div>
                    <Search
                        allowClear
                        placeholder={placeholder}
                        onSearch={handleSearch}
                        // onChange={handleChange}
                        enterButton
                        style={{ width: "300px" }}
                    />
                </div>
                <Button type="primary" onClick={handleReset}>重置</Button>

                <Button type="primary" style={{ marginLeft: "10px" }} icon={<PlusCircleOutlined />} onClick={AddTemplate}>新增</Button>

            </div>
            <div className={styles.list_view}>
                <Table
                    columns={columns}
                    dataSource={data}
                    pagination={{ pageSize: '10' }}
                    scroll={{ y: '500px' }}
                />
            </div>
            <EditModal
                visible={visibleParams.editVisible}
                template={currentTemplate}
                onCancel={() => handleShowModal('editVisible', false)}
                confirmModal={editModal}
                onSubmit={ onSubmit}
            />
            <AddModal
                visible={visibleParams.addVisible}
                onCancel={() => handleShowModal('addVisible', false)}
                confirmModal={addModal}
                onSubmit={ onAddSubmit}
            />

        </div>
    )
}
export default TemplateManage;